@@ -144,7 +144,9 @@ panel.levelplot <-
 ##             col.regions[round(seq(1, numcol.r, length.out = numcol))]
 ##     zcol <- cut(z, at, include.lowest = TRUE, labels = FALSE)
 
-    zcol <- level.colors(z, at, col.regions, colors = TRUE)
+    zcol <-
+        if (region) level.colors(z, at, col.regions, colors = TRUE)
+        else "transparent"
 
     x <- x[subscripts]
     y <- y[subscripts]
@@ -152,9 +154,9 @@ panel.levelplot <-
     minYwid <- if (length(unique(y)) > 1) min(diff(sort(unique(y)))) else 1
     fullZrange <- range(as.numeric(z), finite = TRUE) # for shrinking
     z <- z[subscripts]
-    zcol <- zcol[subscripts]
+    if (region) zcol <- zcol[subscripts]
 
-    if (hasArg(group.number))
+    if (hasGroupNumber())
         group <- list(...)$group.number
     else
         group <- 0
@@ -920,7 +922,7 @@ panel.levelplot.raster <-
     z <- z[subscripts]
     zcol <- zcol[subscripts]
 
-    if (hasArg(group.number))
+    if (hasGroupNumber())
         group <- list(...)$group.number
     else
         group <- 0
